@@ -6,8 +6,8 @@ function (
 	, within = NULL
 	, between = NULL
 	, between_full = NULL
+	, collapse_within = FALSE
 ){
-	from_ezStats_main = ezStats_main(data,dv,sid,within,between,between_full)
-	return(from_ezStats_main$Descriptives)
+	ezStats_main(data,dv,sid,within,between,between_full,collapse_within)
 }
 
